"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Snackbar = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _utils = require("./utils.js");
var _index = require("../../utils/index.js");
var _index2 = require("../../components/index.js");
var _index3 = require("../../context/index.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class Snackbar extends _react.default.Component {
  static defaultProps = {
    anchorOrigin: 'top',
    autoHideDuration: 3000,
    variant: 'solid'
  };
  static contextType = _index3.RNAdvanceComponentContext;
  // @ts-expect-error

  timeout = null;
  windowDimensions = _reactNative.Dimensions.get('window');
  constructor(props) {
    super(props);
    this.state = {
      opacity: new _reactNative.Animated.Value(0)
    };
  }
  init() {
    if (this.props.isVisible === true) {
      _reactNative.Animated.timing(this.state.opacity, {
        toValue: 1,
        duration: 200,
        useNativeDriver: true
      }).start();
    } else {
      if (this.timeout !== null) {
        clearTimeout(this.timeout);
      }
      _reactNative.Animated.timing(this.state.opacity, {
        toValue: 0,
        duration: 200,
        useNativeDriver: true
      }).start();
    }
    if (this.props.isVisible === true && this.props.autoClose === true && this.props.autoHideDuration !== undefined) {
      if (this.timeout !== null) {
        clearTimeout(this.timeout);
      }
      this.timeout = setTimeout(() => {
        this.props.onClose?.();
      }, this.props.autoHideDuration);
    }
  }
  componentDidMount() {
    this.init();
  }
  componentDidUpdate(prevProps, prevState) {
    if (prevProps.isVisible !== this.props.isVisible || prevProps.autoClose !== this.props.autoClose || prevProps.autoHideDuration !== this.props.autoHideDuration || prevState.opacity !== this.state.opacity) {
      this.init();
    }
  }
  componentWillUnmount() {
    if (this.timeout !== null) {
      clearTimeout(this.timeout);
    }
  }
  render() {
    const {
      isVisible,
      message,
      status,
      anchorOrigin,
      onClose,
      variant
    } = this.props;
    const theme = this.context;
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Animated.View, {
      style: [styles.container, {
        top: anchorOrigin === 'top' ? _index.top : this.windowDimensions.height - 90,
        backgroundColor: variant === 'outline' ? theme.colors.background : undefined,
        opacity: this.state.opacity,
        transform: [{
          scale: isVisible ? this.state.opacity.interpolate({
            inputRange: [0, 1],
            outputRange: [0.9, 1]
          }) : 1
        }]
      }],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
        style: [styles.messageContainer, (0, _utils.generateColor)(variant, status)],
        children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
          style: styles.messageSection,
          children: [_utils.statusColorMap[status].icon({
            color: variant !== 'solid' ? _utils.statusColorMap[status].color : 'white',
            size: 26
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
            style: [styles.text, {
              color: variant === 'solid' ? '#ffff' : _utils.statusColorMap[status].textColor
            }],
            numberOfLines: 3,
            children: message
          })]
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index2.IconButton, {
          onPress: onClose,
          defaultIconColor: variant === 'solid' ? '#ffff' : _utils.statusColorMap[status].textColor
        })]
      })
    });
  }
}
exports.Snackbar = Snackbar;
const styles = _reactNative.StyleSheet.create({
  container: {
    maxHeight: 70,
    minHeight: 50,
    marginHorizontal: 5,
    borderRadius: 5,
    flexDirection: 'row',
    alignItems: 'center',
    overflow: 'hidden',
    position: 'absolute',
    zIndex: 1000,
    elevation: 16
  },
  messageContainer: {
    width: '100%',
    height: '100%',
    flexDirection: 'row',
    alignItems: 'center',
    padding: 2
  },
  messageSection: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center'
  },
  text: {
    flex: 1,
    fontSize: 15
  }
});
//# sourceMappingURL=index.js.map