"use strict";

import React from 'react';
import { ActivityIndicator, Image, Modal, TouchableOpacity, StyleSheet, View, Dimensions } from 'react-native';
import { Center, IconButton, ImageZoomViewer } from "../../components/index.js";
import { top } from "../../utils/platformSpecific.js";
import { RNAdvanceComponentContext } from "../../context/index.js";
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
export class ImageViewerModal extends React.Component {
  static contextType = RNAdvanceComponentContext;
  //@ts-expect-error

  windowDimension = Dimensions.get('window');
  constructor(props) {
    super(props);
    this.state = {
      _isModalVisible: false,
      _child: undefined,
      isLoading: false
    };
    this.handleClose = this.handleClose.bind(this);
    this.handleClick = this.handleClick.bind(this);
    this.getChild = this.getChild.bind(this);
  }
  getChild() {
    this.setState({
      _child: React.Children.only(this.props.children)
    });
  }
  componentDidMount() {
    this.getChild();
  }
  componentDidUpdate(prevProps) {
    if (prevProps.children !== this.props.children) {
      this.getChild();
    }
  }
  closeModal(callback) {
    this.setState({
      _isModalVisible: false
    }, callback);
  }
  handleClose() {
    this.setState({
      _isModalVisible: false
    });
  }
  handleClick() {
    this.setState({
      _isModalVisible: true
    });
  }
  render() {
    const {
      modalAnimationType,
      backgroundColor = `rgba(0,0,0,0.5)`,
      defaultIconColor,
      color = 'red',
      isZoomEnable = true
    } = this.props;
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Modal, {
        animationType: modalAnimationType,
        visible: this.state._isModalVisible,
        onRequestClose: this.handleClose,
        transparent: true,
        children: /*#__PURE__*/_jsxs(View, {
          style: [styles.imageContainer, {
            backgroundColor: backgroundColor
          }],
          children: [(this.state.isLoading || !this.state._child?.props.source) && /*#__PURE__*/_jsx(Center, {
            children: /*#__PURE__*/_jsx(ActivityIndicator, {
              size: "large",
              color: color
            })
          }), isZoomEnable ? /*#__PURE__*/_jsx(ImageZoomViewer, {
            cropWidth: this.windowDimension.width,
            cropHeight: this.windowDimension.height,
            imageHeight: this.windowDimension.height,
            imageWidth: this.windowDimension.width,
            children: /*#__PURE__*/_jsx(Image
            // @ts-expect-error
            , {
              source: this.state._child?.props.source,
              style: [styles.image],
              resizeMode: "contain",
              onLoadStart: () => this.setState({
                isLoading: true
              }),
              onLoadEnd: () => this.setState({
                isLoading: false
              })
            })
          }) : /*#__PURE__*/_jsx(Image
          // @ts-expect-error
          , {
            source: this.state._child?.props.source,
            style: [styles.image],
            resizeMode: "contain",
            onLoadStart: () => this.setState({
              isLoading: true
            }),
            onLoadEnd: () => this.setState({
              isLoading: false
            })
          }), /*#__PURE__*/_jsx(View, {
            style: [styles.closeIconContainer, {
              top: top
            }],
            children: /*#__PURE__*/_jsx(IconButton, {
              onPress: this.handleClose,
              color: color,
              defaultIconColor: defaultIconColor
            })
          })]
        })
      }), /*#__PURE__*/_jsx(TouchableOpacity, {
        onPress: this.handleClick,
        children: this.state._child
      })]
    });
  }
}
const styles = StyleSheet.create({
  imageContainer: {
    width: '100%',
    height: '100%'
  },
  image: {
    width: '100%',
    height: '100%'
  },
  closeIconContainer: {
    position: 'absolute',
    right: 4
  }
});
//# sourceMappingURL=index.js.map