"use strict";

import React from 'react';
import { Animated, Dimensions, StyleSheet, Text, View } from 'react-native';
import { generateColor, statusColorMap } from "./utils.js";
import { top } from "../../utils/index.js";
import { IconButton } from "../../components/index.js";
import { RNAdvanceComponentContext } from "../../context/index.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export class Snackbar extends React.Component {
  static defaultProps = {
    anchorOrigin: 'top',
    autoHideDuration: 3000,
    variant: 'solid'
  };
  static contextType = RNAdvanceComponentContext;
  // @ts-expect-error

  timeout = null;
  windowDimensions = Dimensions.get('window');
  constructor(props) {
    super(props);
    this.state = {
      opacity: new Animated.Value(0)
    };
  }
  init() {
    if (this.props.isVisible === true) {
      Animated.timing(this.state.opacity, {
        toValue: 1,
        duration: 200,
        useNativeDriver: true
      }).start();
    } else {
      if (this.timeout !== null) {
        clearTimeout(this.timeout);
      }
      Animated.timing(this.state.opacity, {
        toValue: 0,
        duration: 200,
        useNativeDriver: true
      }).start();
    }
    if (this.props.isVisible === true && this.props.autoClose === true && this.props.autoHideDuration !== undefined) {
      if (this.timeout !== null) {
        clearTimeout(this.timeout);
      }
      this.timeout = setTimeout(() => {
        this.props.onClose?.();
      }, this.props.autoHideDuration);
    }
  }
  componentDidMount() {
    this.init();
  }
  componentDidUpdate(prevProps, prevState) {
    if (prevProps.isVisible !== this.props.isVisible || prevProps.autoClose !== this.props.autoClose || prevProps.autoHideDuration !== this.props.autoHideDuration || prevState.opacity !== this.state.opacity) {
      this.init();
    }
  }
  componentWillUnmount() {
    if (this.timeout !== null) {
      clearTimeout(this.timeout);
    }
  }
  render() {
    const {
      isVisible,
      message,
      status,
      anchorOrigin,
      onClose,
      variant
    } = this.props;
    const theme = this.context;
    return /*#__PURE__*/_jsx(Animated.View, {
      style: [styles.container, {
        top: anchorOrigin === 'top' ? top : this.windowDimensions.height - 90,
        backgroundColor: variant === 'outline' ? theme.colors.background : undefined,
        opacity: this.state.opacity,
        transform: [{
          scale: isVisible ? this.state.opacity.interpolate({
            inputRange: [0, 1],
            outputRange: [0.9, 1]
          }) : 1
        }]
      }],
      children: /*#__PURE__*/_jsxs(View, {
        style: [styles.messageContainer, generateColor(variant, status)],
        children: [/*#__PURE__*/_jsxs(View, {
          style: styles.messageSection,
          children: [statusColorMap[status].icon({
            color: variant !== 'solid' ? statusColorMap[status].color : 'white',
            size: 26
          }), /*#__PURE__*/_jsx(Text, {
            style: [styles.text, {
              color: variant === 'solid' ? '#ffff' : statusColorMap[status].textColor
            }],
            numberOfLines: 3,
            children: message
          })]
        }), /*#__PURE__*/_jsx(IconButton, {
          onPress: onClose,
          defaultIconColor: variant === 'solid' ? '#ffff' : statusColorMap[status].textColor
        })]
      })
    });
  }
}
const styles = StyleSheet.create({
  container: {
    maxHeight: 70,
    minHeight: 50,
    marginHorizontal: 5,
    borderRadius: 5,
    flexDirection: 'row',
    alignItems: 'center',
    overflow: 'hidden',
    position: 'absolute',
    zIndex: 1000,
    elevation: 16
  },
  messageContainer: {
    width: '100%',
    height: '100%',
    flexDirection: 'row',
    alignItems: 'center',
    padding: 2
  },
  messageSection: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center'
  },
  text: {
    flex: 1,
    fontSize: 15
  }
});
//# sourceMappingURL=index.js.map