import type { GestureResponderEvent, PanResponderGestureState, LayoutChangeEvent, ViewStyle } from 'react-native';
export interface ICenterOn {
    x: number;
    y: number;
    scale: number;
    duration: number;
}
export interface IOnMove {
    type: string;
    positionX: number;
    positionY: number;
    scale: number;
    zoomCurrentDistance: number;
}
export interface IOnClick {
    locationX: number;
    locationY: number;
    pageX: number;
    pageY: number;
}
export declare class ImageZoomProps {
    cropWidth: number;
    cropHeight: number;
    imageWidth: number;
    imageHeight: number;
    panToMove?: boolean;
    pinchToZoom?: boolean;
    enableDoubleClickZoom?: boolean;
    clickDistance?: number;
    maxOverflow?: number;
    longPressTime?: number;
    doubleClickInterval?: number;
    /**
     * If provided this will cause the view to zoom and pan to the center point
     * Duration is optional and defaults to 300 ms.
     */
    centerOn?: ICenterOn;
    style?: ViewStyle;
    /**
     * threshold for firing swipe down function
     */
    swipeDownThreshold?: number;
    /**
     * for enabling vertical movement if user doesn't want it
     */
    enableSwipeDown?: boolean;
    /**
     * for disabling focus on image center if user doesn't want it
     */
    enableCenterFocus?: boolean;
    /**
     * for disabling rendering to hardware texture on Android
     */
    useHardwareTextureAndroid?: boolean;
    /**
     * minimum zoom scale
     */
    minScale?: number;
    /**
     * maximum zoom scale
     */
    maxScale?: number;
    /**
     * Whether to use native code to perform animations.
     */
    useNativeDriver?: boolean;
    onClick?: (eventParams: IOnClick) => void;
    onDoubleClick?: (eventParams: IOnClick) => void;
    onLongPress?: (eventParams: IOnClick) => void;
    horizontalOuterRangeOffset?: (offsetX: number) => void;
    onDragLeft?: () => void;
    responderRelease?: (vx: number, scale: number) => void;
    /**
     * If provided, this will be called everytime the map is moved
     */
    onMove?: (position: IOnMove) => void;
    /**
     * If provided, this method will be called when the onLayout event fires
     */
    layoutChange?: (event: LayoutChangeEvent) => void;
    /**
     * function that fires when user swipes down
     */
    onSwipeDown?: () => void;
    /**
     * Allows defining the onMoveShouldSetResponder behavior.
     */
    onMoveShouldSetPanResponder?: (event: GestureResponderEvent, gestureState: PanResponderGestureState) => boolean;
    /**
     * Allows overriding the default onStartShouldSetPanResponder behavior.
     * By default, always becomes the responder
     */
    onStartShouldSetPanResponder?: (event: GestureResponderEvent, gestureState: PanResponderGestureState) => boolean;
    /**
     * Allows overriding the default onPanResponderTerminationRequest behavior.
     * By default, doesn't terminate until the press ends
     */
    onPanResponderTerminationRequest?: (event: GestureResponderEvent, gestureState: PanResponderGestureState) => boolean;
    children?: React.ReactNode;
}
export declare class ImageZoomState {
    centerX?: number;
    centerY?: number;
}
//# sourceMappingURL=index.type.d.ts.map